@@ -9,7 +9,7 @@
 * @copyright  2008 stk2k, sazysoft
 */
 
-class charcoal_Response 
+class Response extends Object
 {
 	private $_data;
 	private $_status;
@@ -19,6 +19,8 @@ class charcoal_Response
 	 */
 	public function __construct()
 	{
+		parent::__construct();
+
 		$this->_data = array();
 	}
 
@@ -75,7 +77,8 @@ class charcoal_Response
 	 */
 	public function __toString()
 	{
-		$str = "[Response]<BR>" . charcoal_System::arrayToString( $this->_data );
+		$str = "[Response]<BR>" . System::arrayToString( $this->_data );
 		return $str;
 	}
 }
+return __FILE__;
