@@ -4,12 +4,12 @@
 *
 * PHP version 5
 *
-* @package    core
+* @package    html_objects
 * @author     stk2k <stk2k@sazysoft.com>
 * @copyright  2008 stk2k, sazysoft
 */
 
-abstract class charcoal_HTMLLeafObject extends charcoal_HTMLObject
+abstract class HTMLLeafObject extends HTMLObject
 {
 	/*
 	 *	󥹥ȥ饯
@@ -24,7 +24,7 @@ abstract class charcoal_HTMLLeafObject extends charcoal_HTMLObject
 	 */
 	public function toHTML()
 	{
-		$conv = charcoal_EncodingConverter::fromString( 'PHP_TO_HTML' );
+		$conv = EncodingConverter::fromString( 'PHP_TO_HTML' );
 
 		$tag = $this->_tag;
 		$html = '<'. $tag;
@@ -45,3 +45,5 @@ abstract class charcoal_HTMLLeafObject extends charcoal_HTMLObject
 		return $html;
 	}
 }
+
+return __FILE__;
\ No newline at end of file
