@@ -9,16 +9,13 @@
 * @copyright  2008 stk2k, sazysoft
 */
 
-interface charcoal_IConfigProvider
+interface IConfigProvider extends IObject
 {
-	/*
-	 * ץХ̾
-	 */
-	public function getProviderName();
-
 	/*
 	 *
 	 */
 	public function load( $config_root, $config_name );
 
 }
+
+return __FILE__;
\ No newline at end of file
