@@ -9,24 +9,8 @@
 * @copyright  2008 stk2k, sazysoft
 */
 
-interface charcoal_IFormModel extends charcoal_IModel
+interface IFormModel extends IModel
 {
-
-	/*
-	 *   ե̾
-	 */
-	public function getFormName();
-
-	/*
-	 *   Υơ
-	 */
-	public function getAnnotation( $field, $type );
-
-	/*
-	 *   Υơͤ
-	 */
-	public function getAnnotationValue( $field, $type );
-
 	/*
 	 *   ϥȥ
 	 */
@@ -35,12 +19,12 @@ interface charcoal_IFormModel extends charcoal_IModel
 	/*
 	 *   եॢΥơ
 	 */
-	public function getFormAnnotation( $type );
+	public function getFormAnnotation( String $type );
 
 	/*
 	 *   եॢΥơͤ
 	 */
-	public function getFormAnnotationValue( $type );
+	public function getFormAnnotationValue( String $type );
 
 	/*
 	 *   ǥեȤΥץ󥯥饹
@@ -55,16 +39,18 @@ interface charcoal_IFormModel extends charcoal_IModel
 	/*
 	 *   ǥեȤΥեɥ饹
 	 */
-	public function getDefaultFieldClass( $field_type );
+	public function getDefaultFieldClass( String $field_type );
 
 	/*
 	 *   ǥեȤΥեɥ
 	 */
-	public function getDefaultFieldStyle( $field_type );
+	public function getDefaultFieldStyle( String $field_type );
 
 	/*
 	 *   ꥹȤθ
 	 */
-	public function getChoiceList( charcoal_ProcedureContext $context, $list_name );
+	public function getChoiceList( String $list_name );
 
 }
+
+return __FILE__;
\ No newline at end of file
