@@ -8,7 +8,7 @@
 * @author     stk2k <stk2k@sazysoft.com>
 * @copyright  2008 stk2k, sazysoft
 */
-interface charcoal_IModel
+interface IModel extends IObject
 {
 	/**
 	 * ǥID
@@ -23,16 +23,17 @@ interface charcoal_IModel
 	/**
 	 * եɤ¸ߤ뤫
 	 */
-	public function fieldExists( $field_name );
+	public function fieldExists( String $field_name );
 
 	/*
 	 *   Υơ
 	 */
-	public function getAnnotation( $field, $type );
+	public function getAnnotation( String $field, String $type );
 
 	/*
 	 *   Υơͤ
 	 */
-	public function getAnnotationValue( $field, $type, $defaultValue = NULL );
+	public function getAnnotationValue( String $field, String $type, $defaultValue = NULL );
 
 }
+return __FILE__;
