@@ -2,6 +2,11 @@
 
 ob_start();
 
+//==================================================================
+// ⡼
+//
+define( 'CHARCOAL_RUNMODE', 'http' );
+
 //==================================================================
 // ١ǥ쥯ȥ
 //
@@ -17,11 +22,6 @@ define ( 'CHARCOAL_HOME' , BASE_DIR . "/charcoal" );
 //
 define( 'WEBAPP_DIR', BASE_DIR . "/web_app" );
 
-//==================================================================
-// 饤֥ǥ쥯ȥ
-//
-define( 'EXTLIB_DIR', BASE_DIR . "/extlib" );
-
 //==================================================================
 // ץꥱ̾
 //
@@ -35,12 +35,7 @@ include( CHARCOAL_HOME . '/charcoal.inc.php');
 //==================================================================
 // ե졼ư
 //
-charcoal_Framework::run();
+Framework::run();
 
 ob_end_flush();
 
-//xdebug_dump_function_trace();
-//xdebug_dump_superglobals();
-//print "peark memory:" . xdebug_peak_memory_usage() . "<BR>";
-
-?>
\ No newline at end of file
