@@ -2,26 +2,26 @@
 
 ob_start();
 
+//==================================================================
+// ⡼
+//
+define( 'CHARCOAL_RUNMODE', 'http' );
+
 //==================================================================
 // ١ǥ쥯ȥ
 //
 define( 'BASE_DIR', dirname(dirname(__FILE__)) );
 
 //==================================================================
-// Charcoalۡǥ쥯ȥ
-//
-define ( 'CHARCOAL_HOME' , BASE_DIR . "/charcoal" );
+// ۡǥ쥯ȥ
+
+define( 'CHARCOAL_HOME', BASE_DIR . '/charcoal' );
 
 //==================================================================
 // WEB_APPǥ쥯ȥ
 //
 define( 'WEBAPP_DIR', BASE_DIR . "/web_app" );
 
-//==================================================================
-// 饤֥ǥ쥯ȥ
-//
-define( 'EXTLIB_DIR', BASE_DIR . "/extlib" );
-
 //==================================================================
 // ץꥱ̾
 //
@@ -35,12 +35,7 @@ include( CHARCOAL_HOME . '/charcoal.inc.php');
 //==================================================================
 // ե졼ư
 //
-charcoal_Framework::run();
+Framework::run();
 
 ob_end_flush();
 
-//xdebug_dump_function_trace();
-//xdebug_dump_superglobals();
-//print "peark memory:" . xdebug_peak_memory_usage() . "<BR>";
-
-?>
\ No newline at end of file
